@@ -194,10 +194,23 @@ class Decorators:
             val = params.get (fd)
             if val is None:
                 continue
+
             if not (len (ops) <= 3 and fd):
                 raise SyntaxError ("invalid require expression on {}".format (fd))
+
             if len (ops) == 1:
-                if hasattr (cond, "search"):
+                if type (cond) is type:
+                    if not isinstance (val, cond):
+                        return 'parameter {} should be an instance of {}'.format (fd, cond)
+                elif isinstance (cond, (list, tuple)):
+                    matched = False
+                    for each in cond:
+                        if isinstance (val, each):
+                            matched = True
+                            break
+                    if not matched:
+                        return 'parameter {} is invalid type'.format (fd)
+                elif hasattr (cond, "search"):
                     if not cond.search (val):
                         return 'parameter {} is invalid'.format (fd)
                 elif val != cond:
