@@ -4,6 +4,7 @@ from functools import wraps
 import re
 import copy
 import inspect
+from urllib.parse import urljoin
 
 RX_RULE = re.compile ("(/<(.+?)>)")
 RE_RULE_NAME_ONLY = re.compile ("/<(?:[a-z]+?:)?([_0-9a-zA-Z]+?)>")
@@ -180,6 +181,21 @@ class Router:
         return map [key][method]
 
     # URL Building ------------------------------------------------
+    def _build_static_url (self, path, base):
+        if path:
+            assert not path.startswith ('/'), 'static path should not start with /'
+        try:
+            base_path = getattr (self.config, base)
+        except AttributeError:
+            base_path = '/'
+        return urljoin (base_path, path)
+
+    def static (self, path):
+        return self._build_static_url (path, 'STATIC_URL')
+
+    def media (self, path):
+        return self._build_static_url (path, 'MEDIA_URL')
+
     def urlfor (self, thing, *args, **kargs):
         if isinstance (thing, FunctionType):
             thing = self._function_names [id (thing)]
