@@ -1,37 +1,43 @@
 import os
 from functools import wraps
+import copy
+from skitai import was as the_was
 
 class TemplateEngine:
     templates_dirs = []
+    DEFAULT_JINJA2_EXTS = {"jinja2.ext.do", "jinja2.ext.loopcontrols"}
 
     def __init__ (self):
         self.jinja_env = None
         self.chameleon = None
-        self._jinja2_patch_options = None
+        self._jinja2_patch_options = (
+            "{{", "}}", "{%", "%}", "{#", "#}", "%", '##',
+            dict (trim_blocks = True, lstrip_blocks = True, newline_sequence = '\n')
+        )
         self._jinja2_filters = {}
+        self._jinja2_extensions = self.DEFAULT_JINJA2_EXTS
         self._template_globals = {}
         self._template_homes = []
 
     def setup_template_engines (self, paths):
         self._template_homes = paths
-
-        # configure jinja --------------------------------------------
-        if self._jinja2_patch_options:
-            self._jinja_overlay ()
-
         try:
-            from jinja2 import Environment
+            import jinja2
         except ImportError:
             pass
         else:
-            loader = self.get_template_loader ()
-            if self.jinja_env:
-                # activated skito_jinja
-                self.jinja_env.loader = loader
-            else:
-                self.jinja_env = Environment (loader = loader)
-
-        # chameleon, deprecated -------------------------------------
+            from ..patches import jinjapatch
+            kargs = self._jinja2_patch_options [-1]
+            if 'loader' not in kargs:
+                kargs ['loader'] = self.get_template_loader ()
+            if 'extensions' not in kargs:
+                kargs ['extensions'] = list (self._jinja2_extensions)
+            self.jinja_env = jinjapatch.overlay (
+                self.app_name,
+                *self._jinja2_patch_options [:-1],
+                **kargs
+            )
+        # chameleon -------------------------------------
         template_dir = os.path.join (paths [0], "templates")
         if os.path.isdir (template_dir):
             try:
@@ -45,6 +51,9 @@ class TemplateEngine:
                     restricted_namespace = False
                 )
 
+    def add_jinja_ext (self, ext):
+        self._jinja2_extensions.add (ext)
+
     def load_jinja_filters (self):
         if not self._jinja2_filters:
             return
@@ -75,21 +84,12 @@ class TemplateEngine:
     # template engine -----------------------------------------------
     def skito_jinja (self, option = 0):
         if option == 0:
-            self.jinja_overlay ("${", "}", "<%", "%>", "<!---", "--->")
+            return self.jinja_overlay ("{{", "}}")
         elif option == 1:
-            self.jinja_overlay ("${", "}", "{%", "%}", "{#", "#}")
-        elif option == 2:
-            self.jinja_overlay ("{*", "*}", "{%", "%}", "{#", "#}")
-        elif option == 3:
-            self.jinja_overlay ("{#", "#}", "{%", "%}", "<!---", "--->")
-        elif option == 4:
-            self.jinja_overlay ("##", "##", "{%", "%}", "<!---", "--->")
+            return self.jinja_overlay ("${", "}")
         elif option == 5:
-            self.jinja_overlay ("{:", ":}", "{%", "%}", "<!---", "--->")
-        elif option == 6:
-            self.jinja_overlay ("<%", "%>", "{%", "%}", "<!---", "--->")
-        elif option == 7:
-            self.jinja_overlay ("{%", "%}", "<%", "%>", "<!---", "--->")
+            return self.jinja_overlay ("{:", ":}", "{%", "%}", "<!---", "--->")
+        raise ValueError ('Invalid template formatting option')
 
     def jinja_overlay (
         self,
@@ -100,7 +100,7 @@ class TemplateEngine:
         comment_start_string = "{#",
         comment_end_string = "#}",
         line_statement_prefix = "%",
-        line_comment_prefix = "%%",
+        line_comment_prefix = "##",
         **karg
     ):
         # delay before app is actual imported
@@ -110,15 +110,6 @@ class TemplateEngine:
             karg
         )
 
-    def _jinja_overlay (self):
-        from ..patches import jinjapatch
-
-        self.jinja_env = jinjapatch.overlay (
-            self.app_name,
-            *self._jinja2_patch_options [:-1],
-            **self._jinja2_patch_options [-1]
-        )
-
     def render (self, was, template_file, _do_not_use_this_variable_name_ = {}, **karg):
         while template_file and template_file [0] == "/":
             template_file = template_file [1:]
@@ -127,11 +118,17 @@ class TemplateEngine:
             assert not karg, "Can't Use Dictionary and Keyword Args Both"
             karg = _do_not_use_this_variable_name_
 
-        karg ["was"] = was
+        context = copy.copy (karg)
         karg.update (self._template_globals)
-
         template = self.get_template (template_file)
-        rendered = template.render (**karg)
+        rendered = template.render (
+            was = was,
+            app = was.app,
+            request = was.request,
+            response = was.response,
+            context = context,
+            **karg
+        )
         return rendered
 
     def get_template (self, name):
