@@ -65,8 +65,8 @@ class SecuredValue:
 	def rollback (self):
 		self.dirty = False
 
-	def config (self, path = None, domain = None, secure = False, http_only = False):
-		self.__config = (path, domain, secure, http_only)
+	def config (self, path = None, domain = None, secure = False, http_only = False, same_site = None):
+		self.__config = (path, domain, secure, http_only, same_site)
 
 	def set_cookie (self, expires):
 		if expires != 0:
