@@ -296,7 +296,7 @@ class WAS (wsgiappservice.WAS):
         _was, args, kargs = self._insert_cloned_was (args, kargs)
         return self.executors.create_thread (_was.ID, target, *args, **kargs).then ()
 
-    def Map (self, tasks, *keys):
+    def Map (self, *commits, **corequests):
         def mapped_api (was, tasks, keys, status):
             results = tasks.fetch ()
             if tasks.count () == 1 and not isinstance (results, (list, tuple)):
@@ -308,24 +308,42 @@ class WAS (wsgiappservice.WAS):
                     continue
 
                 keydata = results [idx]
-                try:
-                    key, field = key.split ('__')
-                except ValueError:
-                    pass
-                else:
-                    if len (keydata) != 1:
+                method, filed = 'fetch', None
+                option = key.split ('__')
+                if len (option) == 3:
+                    key, method, field = option
+                    if method  != 'one':
+                        raise RuntimeError ('must be `one` for specifying field')
+                elif len (option) == 2:
+                    key, method = option
+                    if method not in ('one', 'fetch'):
+                        field, method = method, 'one'
+
+                if method == 'one':
+                    if len (keydata) == 0:
+                        raise was.Error ('410 Partial Not Found')
+                    if len (keydata) > 1:
                         raise was.Error ('409 Conflict')
                     keydata = keydata [0]
                     if field:
                         keydata = keydata [field]
+
                 data [key] = keydata
             return was.API (status, data)
 
         status = "200 OK"
-        if isinstance (tasks, str):
-            status = tasks
-            tasks, keys = keys [0], keys [1:]
-        assert tasks.count () == len (keys), "Count of tasks and keys not nmatch"
+        if commits and isinstance (commits [0], str):
+            status, commits = commits [0], commits [1:]
+
+        keys = []
+        ts = []
+        for k, v in corequests.items ():
+            keys.append (k)
+            ts.append (v)
+        for k in commits:
+            keys.append (None)
+            ts.append (k)
+        tasks = len (ts) == 1 and ts [0] or self.Tasks (*ts)
         return tasks.then (partial (mapped_api, keys = keys, status = status))
 
     def File (self, *args, **karg):
