@@ -1,6 +1,6 @@
 from . import wsgi_executor
 from aquests.protocols.http import respcodes
-from skitai.http_response import catch
+from skitai.backbone.http_response import catch
 
 class Executor (wsgi_executor.Executor):
 	def __call__ (self):
